# Changelog

## [0.1.1](https://github.com/balalofernandez/docx-revisions/compare/docx-revisions-v0.1.0...docx-revisions-v0.1.1) (2026-01-28)


### Bug Fixes

* Add CI ([78f2ef4](https://github.com/balalofernandez/docx-revisions/commit/78f2ef4fb2764054f249460c516dc9d18600f4b4))
* Change to mkdocs ([91c96db](https://github.com/balalofernandez/docx-revisions/commit/91c96dbcdb98ffcb6a6481f885c9434d1d227837))
